@@ -29,33 +29,45 @@
 #include <string.h>
 #include <math.h>
 
-#include "GIRL-PLAYER-KB.h"
 #include <gst/player/player.h>
+#include "GIRL.h"
+#include "GIRL-PLAYER.h"
+#include "GIRL-PLAYER-KB.h"
 
 #define VOLUME_STEPS 20
 
 GST_DEBUG_CATEGORY (play_debug);
 #define GST_CAT_DEFAULT play_debug
 
-typedef struct
-{
-  gchar **uris;
-  guint num_uris;
-  gint cur_idx;
-
-  GstPlayer *player;
-  GstState desired_state;
-
-  gboolean repeat;
-
-  GMainLoop *loop;
-} GstPlay;
-
 static gboolean play_next (GstPlay * play);
 static gboolean play_prev (GstPlay * play);
 static void play_reset (GstPlay * play);
 static void play_set_relative_volume (GstPlay * play, gdouble volume_step);
 
+void
+girl_player_main(gchar *streamuri, gchar *name)
+{
+ 
+	gchar *uri = g_strdup(streamuri);
+		
+	/* if (argc > 1) { */
+	/*   if (g_strrstr (argv[1],"rtsp://") || g_strrstr (argv[1],"http://") || g_strrstr (argv[1],"file://")) */
+	/*     uri = g_strdup (argv[1]); */
+	/*   else */
+	/*     uri = g_strdup_printf ("file://%s", argv[1]); */
+	/* } */
+	/* else { */
+	/*   g_message ("Specify the media file name..<girl-playerplayer filename>"); */
+	/*   return 0; */
+	/* } */
+
+	girl->player_loop = g_main_loop_new (NULL, FALSE);
+	g_main_loop_run (girl->player_loop);
+	gst_deinit();
+	girl->player_status = GIRL_PLAYER_TRUE;
+	exit (0);
+}
+
 static void
 end_of_stream_cb (GstPlayer * player, GstPlay * play)
 {
@@ -414,7 +426,7 @@ play_set_relative_volume (GstPlay * play, gdouble volume_step)
 }
 
 static gchar *
-play_uri_get_display_name (GstPlay * play, const gchar * uri)
+play_uri_get_display_name (GstPlayer * player, const gchar * uri)
 {
   gchar *loc;
 
@@ -430,19 +442,19 @@ play_uri_get_display_name (GstPlay * play, const gchar * uri)
   return loc;
 }
 
-static void
-play_uri (GstPlay * play, const gchar * next_uri)
+void
+play_uri (GstPlayer *player, const gchar * next_uri)
 {
   gchar *loc;
 
-  play_reset (play);
+  play_reset (player);
 
-  loc = play_uri_get_display_name (play, next_uri);
+  loc = play_uri_get_display_name (player, next_uri);
   g_print ("Now playing %s\n", loc);
   g_free (loc);
 
-  g_object_set (play->player, "uri", next_uri, NULL);
-  gst_player_play (play->player);
+  g_object_set (player, "uri", next_uri, NULL);
+  gst_player_play (player);
 }
 
 /* returns FALSE if we have reached the end of the playlist */
@@ -633,8 +645,30 @@ keyboard_cb (const gchar * key_input, gpointer user_data)
   }
 }
 
+void
+girl_player_new (GstPlayer * player, const gchar * next_uri)
+{
+  gst_player_set_uri(player, next_uri);
+}
+
+void
+girl_player_stop (GstPlayer *player)
+{
+  gst_player_stop(player);
+}
+
+void
+girl_player_pause (GstPlayer *player)
+{
+  /* FIXME: Unable to quit after pause is called for the first time. */
+#if 0
+  gst_player_pause(player);
+#endif
+}
+
+#if 0
 int
-girl_player_main (char *uri)
+main (int argc, char **argv)
 {
   GstPlay *play;
   GPtrArray *playlist;
@@ -649,17 +683,94 @@ girl_player_main (char *uri)
   GError *err = NULL;
   GOptionContext *ctx;
   gchar *playlist_file = NULL;
+  GOptionEntry options[] = {
+    {"version", 0, 0, G_OPTION_ARG_NONE, &print_version,
+        "Print version information and exit", NULL},
+    {"shuffle", 0, 0, G_OPTION_ARG_NONE, &shuffle,
+        "Shuffle playlist", NULL},
+    {"interactive", 0, 0, G_OPTION_ARG_NONE, &interactive,
+        "Interactive control via keyboard", NULL},
+    {"volume", 0, 0, G_OPTION_ARG_DOUBLE, &volume,
+        "Volume", NULL},
+    {"playlist", 0, 0, G_OPTION_ARG_FILENAME, &playlist_file,
+        "Playlist file containing input media files", NULL},
+    {"loop", 0, 0, G_OPTION_ARG_NONE, &repeat, "Repeat all", NULL},
+    {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, NULL},
+    {NULL}
+  };
+
+  g_set_prgname ("gst-play");
+
+  ctx = g_option_context_new ("FILE1|URI1 [FILE2|URI2] [FILE3|URI3] ...");
+  g_option_context_add_main_entries (ctx, options, NULL);
+  g_option_context_add_group (ctx, gst_init_get_option_group ());
+  if (!g_option_context_parse (ctx, &argc, &argv, &err)) {
+    g_print ("Error initializing: %s\n", GST_STR_NULL (err->message));
+    g_clear_error (&err);
+    g_option_context_free (ctx);
+    return 1;
+  }
+  g_option_context_free (ctx);
 
   GST_DEBUG_CATEGORY_INIT (play_debug, "play", 0, "gst-play");
 
+  if (print_version) {
+    gchar *version_str;
+
+    version_str = gst_version_string ();
+    g_print ("%s version %s\n", g_get_prgname (), "1.0");
+    g_print ("%s\n", version_str);
+    g_free (version_str);
+
+    g_free (playlist_file);
+
+    return 0;
+  }
+
   playlist = g_ptr_array_new ();
 
+  if (playlist_file != NULL) {
+    gchar *playlist_contents = NULL;
+    gchar **lines = NULL;
+
+    if (g_file_get_contents (playlist_file, &playlist_contents, NULL, &err)) {
+      lines = g_strsplit (playlist_contents, "\n", 0);
+      num = g_strv_length (lines);
+
+      for (i = 0; i < num; i++) {
+        if (lines[i][0] != '\0') {
+          GST_LOG ("Playlist[%d]: %s", i + 1, lines[i]);
+          add_to_playlist (playlist, lines[i]);
+        }
+      }
+      g_strfreev (lines);
+      g_free (playlist_contents);
+    } else {
+      g_printerr ("Could not read playlist: %s\n", err->message);
+      g_clear_error (&err);
+    }
+    g_free (playlist_file);
+    playlist_file = NULL;
+  }
+
+  if (playlist->len == 0 && (filenames == NULL || *filenames == NULL)) {
+    g_printerr ("Usage: %s FILE1|URI1 [FILE2|URI2] [FILE3|URI3] ...",
+        "gst-play");
+    g_printerr ("\n\n"),
+        g_printerr ("%s\n\n",
+        "You must provide at least one filename or URI to play.");
+    /* No input provided. Free array */
+    g_ptr_array_free (playlist, TRUE);
+
+    return 1;
+  }
+
   /* fill playlist */
   if (filenames != NULL && *filenames != NULL) {
     num = g_strv_length (filenames);
     for (i = 0; i < num; ++i) {
       GST_LOG ("command line argument: %s", filenames[i]);
-      add_to_playlist (playlist, uri);
+      add_to_playlist (playlist, filenames[i]);
     }
     g_strfreev (filenames);
   }
@@ -694,3 +805,5 @@ girl_player_main (char *uri)
   gst_deinit ();
   return 0;
 }
+
+#endif
