@@ -24,6 +24,31 @@
 #ifndef GIRL_PLAYER_H
 #define GIRL_PLAYER_H
 
-int girl_player_main (char *uri);
+#include <gst/gst.h>
+#include <gst/player/player.h>
+
+typedef struct
+{
+  gchar **uris;
+  guint num_uris;
+  gint cur_idx;
+
+  GstPlayer *player;
+  GstState desired_state;
+
+  gboolean repeat;
+
+  GMainLoop *loop;
+} GstPlay;
+
+static void play_uri (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_new (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_new (GstPlayer * player, const gchar * next_uri);
+
+void girl_player_quit (GstPlayer *player);
+
+void girl_player_pause (GstPlayer *player);
 
 #endif /* GIRL_PLAYER_H */
