@@ -27,7 +27,10 @@
 #include <clutter-gtk/clutter-gtk.h>
 #include <glib/gstdio.h>
 #include <string.h>
+
 #include "GIRL.h"
+#include "GIRL-GUI.h"
+#include "GIRL-PLAYER.h"
 
 static ChamplainView *champlain_view;
 GApplication *app;
@@ -51,6 +54,7 @@ GtkWidget *search_selector = NULL;
 gchar *list_item_data_key ="list_item_data";
 
 GtkWidget *girl_app;
+GstPlayer *player;
 
 extern struct GirlMedia *media;
 
@@ -68,14 +72,28 @@ search_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
 
 static void
 listen_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
-  /* girl_player_main (")http://bbcwssc.ic.llnwd.net/stream/bbcwssc_mp1_ws-eieuk"); */
+  player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new
+				      (NULL));
+  girl_player_new(player, "http://bbcwssc.ic.llnwd.net/stream/bbcwssc_mp1_ws-eieuk");
   g_print("Listening to BBC World Service\n");
+  gst_player_play(player);
+  g_print("%s\n", __FUNCTION__);
+  return;
+}
+
+static void
+stop_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
+  girl_player_stop(player);
   return;
 }
 
 static void
 pause_station(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
+  /* FIXME: Removing Pause.  Can't quit after gst_player_pause is called. */
+#if 0
+  girl_player_pause(player);
   g_print("Pause Internet Radio Station\n");
+#endif
   return;
 }
 
@@ -111,6 +129,7 @@ about_program_cb(GSimpleAction *simple, GVariant *parameter, gpointer user_data)
 
 static void
 quit_program(GSimpleAction *simple, GVariant *parameter, gpointer user_data) {
+  girl_player_stop(player);
   g_application_quit(app);
   gst_deinit();
   return;
@@ -211,7 +230,7 @@ static void
 girl_window_cb (GtkApplication *app,
 		gpointer user_data)
 {
-  GtkWidget *widget, *grid, *toolbar, *new, *search, *listen, *pause, *prev, *stations, *next, *station, *program, *quit;
+  GtkWidget *widget, *grid, *toolbar, *new, *search, *listen, *stop, *prev, *stations, *next, *station, *program, *quit;
 	
 	window = gtk_application_window_new (app);
 	widget = gtk_champlain_embed_new();
@@ -238,12 +257,12 @@ girl_window_cb (GtkApplication *app,
 	gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM(listen), "Listen Internet Radio Station");
 	g_signal_connect(listen, "clicked", G_CALLBACK (listen_station), GTK_WINDOW (window));
 
-	pause = gtk_tool_button_new(gtk_image_new_from_icon_name(NULL, GTK_ICON_SIZE_BUTTON), "Pause");
-	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(pause), TRUE);
-	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), GTK_TOOL_ITEM(pause), 3);
-	gtk_widget_show (GTK_WIDGET(pause));
-	gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM(pause), "Pause Internet Radio Station");
-	g_signal_connect(pause, "clicked", G_CALLBACK (pause_station), GTK_WINDOW (window));
+	stop = gtk_tool_button_new(gtk_image_new_from_icon_name(NULL, GTK_ICON_SIZE_BUTTON), "Stop");
+	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(stop), TRUE);
+	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), GTK_TOOL_ITEM(stop), 3);
+	gtk_widget_show (GTK_WIDGET(stop));
+	gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM(stop), "Stop Internet Radio Station");
+	g_signal_connect(stop, "clicked", G_CALLBACK (stop_station), GTK_WINDOW (window));
 
 	prev = gtk_tool_button_new(gtk_image_new_from_icon_name(NULL, GTK_ICON_SIZE_BUTTON), "Prev");
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(prev), TRUE);
