@@ -148,9 +148,10 @@ gboolean girl_player_backend_init (int *argc,char **argv[])
 void girl_player_backend_stop (GMainLoop *loop)
 {
 
-	girl->player_status = GIRL_PLAYER_FALSE;
-	gst_element_set_state(media->pipeline, GST_STATE_NULL);
-	gst_object_unref(GST_OBJECT (media->pipeline));
-	gst_deinit();
-	g_main_loop_quit (loop);
+  if (girl->player_status == GIRL_PLAYER_TRUE) {
+    gst_element_set_state(media->pipeline, GST_STATE_NULL);
+    gst_object_unref(GST_OBJECT (media->pipeline));
+    gst_deinit();
+    g_main_loop_quit (loop);
+  }
 }
